@@ -1,6 +1,7 @@
 import logging
 
 import aiohttp
+import orjson
 from tenacity import retry, retry_if_exception, stop_after_attempt, wait_exponential
 
 from aporia.consts import LOGGER_NAME
@@ -12,7 +13,7 @@ logger = logging.getLogger(LOGGER_NAME)
 QUERY_MAX_ATTEMPTS = 4
 QUERY_TIMEOUT = 10
 QUERY_RETRY_INITIAL_SLEEP = 2
-DEFAULT_TIMEOUT_SEC = 300
+DEFAULT_TIMEOUT_SEC = 30
 
 
 class GraphQLClient:
@@ -28,11 +29,14 @@ class GraphQLClient:
         """
         logger.debug("Initializing GraphQL client.")
         if not host.startswith("http"):
-            host = f"https://{host}"
+            host = "https://{}".format(host)
 
-        self.request_url = f"{host}:{port}/v1/controller/graphql"
-        self.headers = {"Authorization": f"Bearer {token}"}
-        self.session: aiohttp.ClientSession = None  # type: ignore
+        self.request_url = "{}:{}/v1/controller/graphql".format(host, port)
+        self.headers = {
+            "Authorization": "Bearer {}".format(token),
+            "Content-Type": "application/json",
+        }
+        self.session = None
 
     async def open(self):
         """Opens the http session.
@@ -75,24 +79,24 @@ class GraphQLClient:
         Returns:
             dict: GraphQL query result
         """
-        logger.debug(f"Sending GraphQL query: {query}, variables: {variables}")
+        logger.debug("Sending GraphQL query: {}, variables: {}".format(query, variables))
         # Note: By default, aiohttp uses SSL and verifies the certificate in HTTPS requests
-        async with self.session.post(
+        async with self.session.post(  # type: ignore
             url=self.request_url,
-            json={"query": query, "variables": variables},
+            data=orjson.dumps({"query": query, "variables": variables}),
             timeout=aiohttp.ClientTimeout(total=timeout),
         ) as response:
 
             if response.status != 200:
                 if response.status == 400:
                     errors = (await response.json())["errors"]  # type: ignore
-                    raise AporiaError(errors[0]["message"])
+                    raise AporiaError("Server Error: {}".format(errors[0]["message"]))
 
                 elif response.status == 401:
                     raise AporiaError("Authentication failed, please check your token.")
 
                 else:
-                    raise AporiaError(f"Unexpected HTTP error {response.status}")
+                    raise AporiaError("Unexpected HTTP error {}".format(response.status))
 
             return (await response.json())["data"]  # type: ignore
 
